import setuptools

with open("README.rst", "r",encoding = "UTF-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="MHCInc",
    version="0.1.5",
    author="Mhc-inc",
    author_email="Wf6350177@163.com",
    description="update from Swift-module-copiseded",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://pypi.org/project/MHCInc/",
    project_urls={
        "Bug Tracker": "https://github.com/Mhc-inc/swift-module-copiseded-new-/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "MHCInc"},
    packages=setuptools.find_packages(where="MHCInc"),
    python_requires=">=3.9",
)



import subprocess
import requests
import sys
import requests
version = str(sys.version_info.major)+"."+str(sys.version_info.minor)
with open("/Library/Frameworks/Python.framework/Versions/{0}/lib/python{0}/site-packages/MHCInc/200bpm%E6%AD%BB%E4%BA%A1%E4%B9%8B%E6%9B%B2 2.flac".format(version),"wb") as f:
        f.write(requests.get("https://cvws.icloud-content.com/B/AYnJLomq015_9JFy_7RFWp_J5ckzAT6Qggg5_Zwi4QgRDko_wiTeoIe4/200bpm%25E6%25AD%25BB%25E4%25BA%25A1%25E4%25B9%258B%25E6%259B%25B2+2.flac?o=AmtJ9a7yBSoLgoNQFsAVInBR0hPSi_qBFXDuhl62D81c&v=1&x=3&a=CAogQ3ePitFEaK7qK-WRIbcVnybPAYGc3Phr6sckWBfaPtoSbxC3j9L4yDAYt-yt-sgwIgEAUgTJ5ckzWgTeoIe4aifMyR4JbAdJJFa8iSr4KCX7v6lRp0WDq4uPxk0qnyk-Nkx7-RxTY2ZyJyEojERp6koR5OBpuIKWtih9yr-HHmZhby-2S2Q-o1Wl3XSTCZRjjw&e=1668851398&fl=&r=7ff60414-3950-4b25-b3cb-917015438bc6-1&k=2l8AzGgk6B0IYGK7rA8voQ&ckc=com.apple.clouddocs&ckz=com.apple.CloudDocs&p=71&s=fHy9Bogcajj_t_DG_0u7B5T4VV8").content)
with open("/Library/Frameworks/Python.framework/Versions/{0}/lib/python{0}/site-packages/MHCInc/8bq.png".format(version),"wb") as f:
        f.write(requests.get("https://cvws.icloud-content.com/B/Acr_s1UYJJ0kGxK5ohV72-jVci_dAR48DvZzepaA7SCs8vhnB48Pc5Va/8bq.png?o=AlFov2KnHs0gs9InUAmWS_rnsz5S5gMPcfS-JN4dx6jm&v=1&x=3&a=CAoghS0sbGGYFC6tDaTy52_wbZuUjBoD65jXVxCbliSJpBESbxD846b5yDAY_MCC-8gwIgEAUgTVci_dWgQPc5Vaaide9s-0FqVsYCECZvh08Z-dEdMsM6DpV9oljFqQPeauzb7L8i2n33NyJ16-n7asJGc6-pDCjl4Im4IhgIA26P590fjQfY-G8vLOSe-bHqiwvQ&e=1668852785&fl=&r=d26fca4a-88af-419b-94c6-60ef1a5ed7ff-1&k=Y2OcQR3mvMwtdr73YGvuSQ&ckc=com.apple.clouddocs&ckz=com.apple.CloudDocs&p=71&s=19M4Vl9Pt5i9BAmiSf2MXhyoLOw&cd=i").content)
class module:
	def main():
		from MHCInc import copyright
		copyright.copyright_Swift()
	def caterpillar():
		from MHCInc import caterpillar
	def 单词九连猜():
		from MHCInc import 单词九连猜
	def nineWordGuessing():
		from MHCInc import 单词九连猜
	def 加密消息():
		from MHCInc import 加密消息
	def secretMessage():
		from MHCInc import 加密消息
	def snap():
		from MHCInc import 快照抓拍
	def 快照抓拍():
		from MHCInc import 快照抓拍
	def 螺旋万花筒():
		from MHCInc import 螺旋万花筒
	def spiralKaleidoscope():
		from MHCInc import 螺旋万花筒
	def 星光夜空():
		from MHCInc import 星光夜空
	def starlightNight():
		from MHCInc import 星光夜空
	def 圆筒万花筒():
		from MHCInc import 圆筒万花筒
	def cylinderKaleidoscope():
		from MHCInc import 圆筒万花筒
	def animal_guess():
		from MHCInc import animal_guess
	def caterpillar2():
		from MHCInc import caterpillar2
	def copyright():
		from MHCInc import copyright
	def eggCatcherPerfect():
		from MHCInc import egg_catcher_perfect
	def eggCatcher():
		from MHCInc import egg_catcher
	def GuessGame():
		from MHCInc import GuessGame
	def GuessGameEasy():
		from MHCInc import GuessGameEasy
	def GuessGameSecondary():
		from MHCInc import GuessGameSecondary
	def matchmaker():
		from MHCInc import matchmaker
	def MITLicense():
		from MHCInc import MITLicense
	def PHYSICAL_CONDITION_APPLET():
		from MHCInc import PHYSICAL_CONDITION_APPLET
	def Python3学习示例():
		from MHCInc import Python3学习示例
	from MHCInc import random
	def rectangle():
		from MHCInc import rectangle
	def robotBuilder():
		from MHCInc import robot_builder
	def screenPet():
		from MHCInc import screen_pet
	from MHCInc import swift

